@@ -15,7 +15,7 @@
 #include <qkeycode.h>
 #endif
 
-#include <qobjcoll.h>
+#include <qobjectlist.h>
 #include <qframe.h>
 #include <qpainter.h>
 #include <qcursor.h>
