@@ -19,7 +19,7 @@
 #include <qwidget.h>
 #include <qobject.h>
 #include <qpoint.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 #include <qpushbutton.h>
 #include <qstrlist.h>
