@@ -7,7 +7,7 @@
 
 #include "stabbar.h"
 
-#include <qapp.h>
+#include <qapplication.h>
 #include <qwmatrix.h>
 #include <qpushbutton.h>
 #include <qpainter.h>
