@@ -9,7 +9,7 @@
 #define STABBAR_H
 
 #include <qwidget.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 
 class QPushButton;
@@ -102,7 +102,7 @@ private:
 
   TabPos tabPos;
   BarPainter* barPainter;
-  QList<TabBarData> *mainData;
+  QPtrList<TabBarData> *mainData;
   int _currentTab;
   int leftTab;
 
