@@ -1,4 +1,4 @@
-// $Id: brkpt.cpp,v 1.30.2.1 2001/12/29 20:12:16 jsixt Exp $
+// $Id: brkpt.cpp,v 1.30.2.2 2004/05/19 20:35:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -373,12 +373,12 @@ void BreakpointTable::initListAndIcons()
     QPixmap brktmp = loader->loadIcon("brktmp.xpm");
     QPixmap brkcond = loader->loadIcon("brkcond.xpm");
 #else
-    QPixmap brkena = BarIcon("brkena.xpm");
-    QPixmap brkdis = BarIcon("brkdis.xpm");
-    QPixmap watchena = BarIcon("watchena.xpm");
-    QPixmap watchdis = BarIcon("watchdis.xpm");
-    QPixmap brktmp = BarIcon("brktmp.xpm");
-    QPixmap brkcond = BarIcon("brkcond.xpm");
+    QPixmap brkena = UserIcon("brkena.xpm");
+    QPixmap brkdis = UserIcon("brkdis.xpm");
+    QPixmap watchena = UserIcon("watchena.xpm");
+    QPixmap watchdis = UserIcon("watchdis.xpm");
+    QPixmap brktmp = UserIcon("brktmp.xpm");
+    QPixmap brkcond = UserIcon("brkcond.xpm");
 #endif
     /*
      * There are 16 different pixmaps: The basic enabled or disabled
