@@ -1,4 +1,4 @@
-// $Id: dbgdriver.h,v 1.16.2.2 2002/03/09 21:22:21 jsixt Exp $
+// $Id: dbgdriver.h,v 1.16.2.3 2003/09/07 18:36:22 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -6,8 +6,8 @@
 #ifndef DBGDRIVER_H
 #define DBGDRIVER_H
 
-#include <qqueue.h>
-#include <qlist.h>
+#include <qptrqueue.h>
+#include <qptrlist.h>
 #include <qfile.h>
 #include <kprocess.h>
 
