@@ -1,4 +1,4 @@
-// $Id: dbgmainwnd.cpp,v 1.50.2.2 2002/01/31 20:14:03 jsixt Exp $
+// $Id: dbgmainwnd.cpp,v 1.50.2.4 2003/08/16 16:22:28 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -134,10 +134,10 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
 
     connect(m_debugger, SIGNAL(memoryDumpChanged(const QString&, QList<MemoryDump>&)),
 	    m_memoryWindow, SLOT(slotNewMemoryDump(const QString&, QList<MemoryDump>&)));
-    connect(m_debugger, SIGNAL(saveProgramSpecific(KSimpleConfig*)),
-	    m_memoryWindow, SLOT(saveProgramSpecific(KSimpleConfig*)));
-    connect(m_debugger, SIGNAL(restoreProgramSpecific(KSimpleConfig*)),
-	    m_memoryWindow, SLOT(restoreProgramSpecific(KSimpleConfig*)));
+    connect(m_debugger, SIGNAL(saveProgramSpecific(KConfigBase*)),
+	    m_memoryWindow, SLOT(saveProgramSpecific(KConfigBase*)));
+    connect(m_debugger, SIGNAL(restoreProgramSpecific(KConfigBase*)),
+	    m_memoryWindow, SLOT(restoreProgramSpecific(KConfigBase*)));
 
     // thread window
     connect(m_debugger, SIGNAL(threadsChanged(QList<ThreadInfo>&)),
@@ -307,7 +307,7 @@ void DebuggerMainWnd::initToolbar()
     toolbar->insertButton(BarIcon("brkpt.xpm"),ID_BRKPT_SET, true,
 			   i18n("Breakpoint"));
     toolbar->insertSeparator();
-    toolbar->insertButton(BarIcon("search.xpm"),ID_VIEW_FINDDLG, true,
+    toolbar->insertButton(BarIcon("find.xpm"),ID_VIEW_FINDDLG, true,
 			   i18n("Search"));
 
     connect(toolbar, SIGNAL(clicked(int)), SLOT(menuCallback(int)));
