@@ -1,4 +1,4 @@
-// $Id: dbgmainwnd.h,v 1.23 2000/11/05 10:02:16 jsixt Exp $
+// $Id: dbgmainwnd.h,v 1.24 2001/04/28 20:55:07 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -62,6 +62,8 @@ protected:
 
     QPopupMenu* m_menuRecentExecutables;
 
+    QPopupMenu* m_popupLocals;
+
     QTimer m_backTimer;
 
 protected:
@@ -109,6 +111,8 @@ public slots:
     void slotProgramStopped();
     void slotBackTimer();
     void slotRecentExec(int item);
+    void slotLocalsPopup(int item, const QPoint& pt);
+    void slotLocalsToWatch();
 };
 
 #endif // DBGMAINWND_H
