@@ -1,4 +1,4 @@
-// $Id: debugger.cpp,v 1.106.2.1 2002/01/01 17:01:51 jsixt Exp $
+// $Id: debugger.cpp,v 1.106.2.5 2003/08/16 16:22:28 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -9,12 +9,12 @@
 #include "typetable.h"
 #include "exprwnd.h"
 #include "pgmsettings.h"
+#include "programconfig.h"
 #include "valarray.h"
 #include <qregexp.h>
 #include <qfileinfo.h>
 #include <qlistbox.h>
 #include <kapp.h>
-#include <ksimpleconfig.h>
 #include <kconfig.h>
 #if QT_VERSION >= 200
 #include <klocale.h>			/* i18n */
@@ -136,7 +136,7 @@ bool KDebugger::debugProgram(const QString& name)
     // get debugger command from per-program settings
     if (m_programConfig != 0) {
 	m_programConfig->setGroup(GeneralGroup);
-	m_debuggerCmd = m_programConfig->readEntry(DebuggerCmdStr);
+	m_debuggerCmd = readDebuggerCmd();
 	// get terminal emulation level
 	m_ttyLevel = TTYLevel(m_programConfig->readNumEntry(TTYLevelEntry, ttyFull));
     }
@@ -539,20 +539,8 @@ void KDebugger::openProgramConfig(const QString& name)
     }
     pgmConfigFile += ".kdbgrc." + fi.fileName();
     TRACE("program config file = " + pgmConfigFile);
-    // check whether we can write to the file
-    QFile file(pgmConfigFile);
-    bool readonly = true;
-    bool openit = true;
-    if (file.open(IO_ReadWrite)) {	/* don't truncate! */
-	readonly = false;
-	// the file exists now
-    } else if (!file.open(IO_ReadOnly)) {
-	/* file does not exist and cannot be created: don't use it */
-	openit = false;
-    }
-    if (openit) {
-	m_programConfig = new KSimpleConfig(pgmConfigFile, readonly);
-    }
+
+    m_programConfig = new ProgramConfig(pgmConfigFile);
 }
 
 const char EnvironmentGroup[] = "Environment";
@@ -614,7 +602,7 @@ void KDebugger::restoreProgramSettings()
      * We ignore file version for now we will use it in the future to
      * distinguish different versions of this configuration file.
      */
-    m_debuggerCmd = m_programConfig->readEntry(DebuggerCmdStr);
+    // m_debuggerCmd has been read in already
     // m_ttyLevel has been read in already
     QString pgmArgs = m_programConfig->readEntry(ProgramArgs);
     QString pgmWd = m_programConfig->readEntry(WorkingDirectory);
@@ -669,6 +657,33 @@ void KDebugger::restoreProgramSettings()
     emit restoreProgramSpecific(m_programConfig);
 }
 
+/**
+ * Reads the debugger command line from the program settings. The config
+ * group must have been set by the caller.
+ */
+QString KDebugger::readDebuggerCmd()
+{
+    QString debuggerCmd = m_programConfig->readEntry(DebuggerCmdStr);
+
+    // always let the user confirm the debugger cmd if we are root
+    if (::geteuid() == 0)
+    {
+	if (!debuggerCmd.isEmpty()) {
+	    QString msg = i18n(
+		"The settings for this program specify "
+		"the following debugger command:\n%1\n"
+		"Shall this command be used?");
+	    if (KMessageBox::warningYesNo(parentWidget(), msg.arg(debuggerCmd))
+		!= KMessageBox::Yes)
+	    {
+		// don't use it
+		debuggerCmd = QString();
+	    }
+	}
+    }
+    return debuggerCmd;
+}
+
 /*
  * Breakpoints are saved one per group.
  */
@@ -680,7 +695,7 @@ const char Temporary[] = "Temporary";
 const char Enabled[] = "Enabled";
 const char Condition[] = "Condition";
 
-void KDebugger::saveBreakpoints(KSimpleConfig* config)
+void KDebugger::saveBreakpoints(ProgramConfig* config)
 {
     QString groupName;
     int i = 0;
@@ -725,7 +740,7 @@ void KDebugger::saveBreakpoints(KSimpleConfig* config)
     }
 }
 
-void KDebugger::restoreBreakpoints(KSimpleConfig* config)
+void KDebugger::restoreBreakpoints(ProgramConfig* config)
 {
     QString groupName;
     QString fileName;
@@ -1201,6 +1216,8 @@ bool KDebugger::handlePrint(CmdQueueItem* cmd, const char* output)
 
 	dummyParent->appendChild(variable);
 	dummyParent->setDeleteChildren(true);
+	// expand the first level for convenience
+	variable->setExpanded(true);
 	TRACE("update ptr: " + cmd->m_expr->getText());
 	cmd->m_exprWnd->updateExpr(cmd->m_expr, dummyParent);
 	delete dummyParent;
