@@ -1,4 +1,4 @@
-// $Id: debugger.h,v 1.66 2000/08/18 19:22:48 jsixt Exp $
+// $Id: debugger.h,v 1.66.2.2 2003/08/16 16:22:29 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -20,7 +20,8 @@ class VarTree;
 class ProgramTypeTable;
 class KTreeViewItem;
 class KConfig;
-class KSimpleConfig;
+class KConfigBase;
+class ProgramConfig;
 class QListBox;
 class RegisterInfo;
 class ThreadInfo;
@@ -306,8 +307,8 @@ protected:
     void newBreakpoint(const char* output);
     void updateBreakList(const char* output);
     bool stopMayChangeBreakList() const;
-    void saveBreakpoints(KSimpleConfig* config);
-    void restoreBreakpoints(KSimpleConfig* config);
+    void saveBreakpoints(ProgramConfig* config);
+    void restoreBreakpoints(ProgramConfig* config);
 
     bool m_haveExecutable;		/* has an executable been specified */
     bool m_programActive;		/* is the program active (possibly halting in a brkpt)? */
@@ -322,9 +323,10 @@ protected:
     QDict<EnvVar> m_envVars;		/* environment variables set by user */
     QStrList m_sharedLibs;		/* shared libraries used by program */
     ProgramTypeTable* m_typeTable;	/* known types used by the program */
-    KSimpleConfig* m_programConfig;	/* program-specific settings (brkpts etc) */
+    ProgramConfig* m_programConfig;	/* program-specific settings (brkpts etc) */
     void saveProgramSettings();
     void restoreProgramSettings();
+    QString readDebuggerCmd();
 
     // debugger process
     DebuggerDriver* m_d;
@@ -459,12 +461,12 @@ signals:
     /**
      * Gives other objects a chance to save program specific settings.
      */
-    void saveProgramSpecific(KSimpleConfig* config);
+    void saveProgramSpecific(KConfigBase* config);
 
     /**
      * Gives other objects a chance to restore program specific settings.
      */
-    void restoreProgramSpecific(KSimpleConfig* config);
+    void restoreProgramSpecific(KConfigBase* config);
 
 protected:
     ExprWnd& m_localVariables;
