@@ -1,4 +1,4 @@
-// $Id: exprwnd.cpp,v 1.19.2.3 2002/01/19 21:43:07 jsixt Exp $
+// $Id: exprwnd.cpp,v 1.19.2.5 2004/05/19 20:35:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -253,7 +253,7 @@ ExprWnd::ExprWnd(QWidget* parent, const char* name) :
     KIconLoader* loader = kapp->getIconLoader();
     m_pixPointer = loader->loadIcon("pointer.xpm");
 #else
-    m_pixPointer = BarIcon("pointer.xpm");
+    m_pixPointer = UserIcon("pointer.xpm");
 #endif
     if (m_pixPointer.isNull())
 	TRACE("Can't load pointer.xpm");
@@ -489,6 +489,7 @@ void ExprWnd::replaceChildren(VarTree* display, VarTree* newValues)
 	vNew->m_value = v->m_value;
 	vNew->m_type = v->m_type;
 	vNew->setDelayedExpanding(vNew->m_varKind == VarTree::VKpointer);
+	vNew->setExpanded(v->isExpanded());
 	display->appendChild(vNew);
 	// recurse
 	replaceChildren(vNew, v);
