@@ -1,4 +1,4 @@
-// $Id: gdbdriver.cpp,v 1.22.2.4 2002/01/19 21:25:58 jsixt Exp $
+// $Id: gdbdriver.cpp,v 1.22.2.9 2004/05/19 20:19:58 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -635,6 +635,7 @@ static bool isErrorExpr(const char* output)
 	strncmp(output, "Attempt to take contents of ", 28) == 0 ||
 	strncmp(output, "Attempt to use a type name as an expression", 43) == 0 ||
 	strncmp(output, "There is no member or method named", 34) == 0 ||
+	strncmp(output, "A parse error in expression", 27) == 0 ||
 	strncmp(output, "No symbol \"", 11) == 0 ||
 	strncmp(output, "Internal error: ", 16) == 0;
 }
@@ -710,7 +711,15 @@ VarTree* GdbDriver::parseQCharArray(const char* output, bool wantErrorValue, boo
 
     // check if this is an error indicating that gdb does not know about QString::null
     if (cmds[DCprintQStringStruct].fmt == printQStringStructFmt &&
-	strncmp(p, "Internal error: could not find static variable null", 51) == 0)
+	(strncmp(p, "Internal error: could not find static variable null", 51) == 0 ||
+	 /*
+	  * At least gdb 5.2.1 reports the following error when it accesses
+	  * QString::null. Checking for it can result in false positives
+	  * (where the error is actually triggered by a real NULL pointer
+	  * in a badly initialized QString variable) but the consequences
+	  * are mild.
+	  */
+	 strncmp(p, "Cannot access memory at address 0x0", 35) == 0))
     {
 	/* QString::null doesn't work, use an alternate expression */
 	cmds[DCprintQStringStruct].fmt = printQStringStructNoNullFmt;
@@ -1420,12 +1429,20 @@ static void parseFrameInfo(const char*& s, QString& func,
      * Skip parameters. But notice that for complicated conversion
      * functions (eg. "operator int(**)()()", ie. convert to pointer to
      * pointer to function) as well as operator()(...) we have to skip
-     * additional pairs of parentheses.
+     * additional pairs of parentheses. Furthermore, recent gdbs write the
+     * demangled name followed by the arguments in a pair of parentheses,
+     * where the demangled name can end in "const".
      */
     do {
 	skipNestedWithString(p, '(', ')');
 	while (isspace(*p))
 	    p++;
+	// skip "const"
+	if (strncmp(p, "const", 5) == 0) {
+	    p += 5;
+	    while (isspace(*p))
+		p++;
+	}
     } while (*p == '(');
 
     // check for file position
@@ -1503,18 +1520,27 @@ static bool parseFrame(const char*& s, int& frameNo, QString& func,
 {
     // Example:
     //  #1  0x8048881 in Dl::Dl (this=0xbffff418, r=3214) at testfile.cpp:72
+    //  Breakpoint 3, Cl::f(int) const (this=0xbffff3c0, x=17) at testfile.cpp:155
 
     // must start with a hash mark followed by number
-    if (s[0] != '#' || !isdigit(s[1]))
+    // or with "Breakpoint " followed by number and comma
+    if (s[0] == '#') {
+	if (!isdigit(s[1]))
+	    return false;
+	s++;				/* skip the hash mark */
+    } else if (strncmp(s, "Breakpoint ", 11) == 0) {
+	if (!isdigit(s[11]))
+	    return false;
+	s += 11;			/* skip "Breakpoint" */
+    } else
 	return false;
 
-    s++;				/* skip the hash mark */
     // frame number
     frameNo = atoi(s);
     while (isdigit(*s))
 	s++;
-    // space
-    while (isspace(*s))
+    // space and comma
+    while (isspace(*s) || *s == ',')
 	s++;
     parseFrameInfo(s, func, file, lineNo, address);
     return true;
@@ -1570,9 +1596,8 @@ bool GdbDriver::parseBreakList(const char* output, QList<Breakpoint>& brks)
 	// get Type
 	while (isspace(*p))
 	    p++;
-	Breakpoint::Type bpType;
+	Breakpoint::Type bpType = Breakpoint::breakpoint;
 	if (strncmp(p, "breakpoint", 10) == 0) {
-	    bpType = Breakpoint::breakpoint;
 	    p += 10;
 	} else if (strncmp(p, "hw watchpoint", 13) == 0) {
 	    bpType = Breakpoint::watchpoint;
@@ -1865,12 +1890,25 @@ bool GdbDriver::parseChangeExecutable(const char* output, QString& message)
     m_haveCoreFile = false;
 
     /*
-     * The command is successful if there is no output or the single
-     * message (no debugging symbols found)...
+     * Lines starting with the following do not indicate errors:
+     *     Using host libthread_db
+     *     (no debugging symbols found)
      */
-    return
-	output[0] == '\0' ||
-	strcmp(output, "(no debugging symbols found)...") == 0;
+    while (strncmp(output, "Using host libthread_db", 23) == 0 ||
+	   strncmp(output, "(no debugging symbols found)", 28) == 0)
+    {
+	// this line is good, go to the next one
+	const char* end = strchr(output, '\n');
+	if (end == 0)
+	    output += strlen(output);
+	else
+	    output = end+1;
+    }
+
+    /*
+     * If we've parsed all lines, there was no error.
+     */
+    return output[0] == '\0';
 }
 
 bool GdbDriver::parseCoreFile(const char* output)
@@ -2022,43 +2060,84 @@ void GdbDriver::parseRegisters(const char* output, QList<RegisterInfo>& regs)
 	// skip space
 	while (isspace(*output))
 	    output++;
-	// the rest of the line is the register value
-	start = output;
-	output = strchr(output,'\n');
-	if (output == 0)
-	    output = start + strlen(start);
-	value = FROM_LATIN1(start, output-start).simplifyWhiteSpace();
-
-	if (*output != '\0')
-	    output++;			/* skip '\n' */
 
 	RegisterInfo* reg = new RegisterInfo;
 	reg->regName = regName;
 
 	/*
-	 * We split the raw from the cooked values. For this purpose, we
-	 * split off the first token (separated by whitespace). It is the
-	 * raw value. The remainder of the line is the cooked value.
+	 * If we find a brace now, this is a vector register. We look for
+	 * the closing brace and treat the result as cooked value.
 	 */
-	int pos = value.find(' ');
-	if (pos < 0) {
-	    reg->rawValue = value;
-	    reg->cookedValue = QString();
-	} else {
-	    reg->rawValue = value.left(pos);
-	    reg->cookedValue = value.mid(pos+1,value.length());
+	if (*output == '{')
+	{
+	    start = output;
+	    skipNested(output, '{', '}');
+	    value = FROM_LATIN1(start, output-start).simplifyWhiteSpace();
+	    // skip space, but not the end of line
+	    while (isspace(*output) && *output != '\n')
+		output++;
+	    // get rid of the braces at the begining and the end
+	    value.remove(0, 1);
+	    if (value[value.length()-1] == '}') {
+		value = value.left(value.length()-1);
+	    }
+	    // gdb 5.3 doesn't print a separate set of raw values
+	    if (*output == '{') {
+		// another set of vector follows
+		// what we have so far is the raw value
+		reg->rawValue = value;
+
+		start = output;
+		skipNested(output, '{', '}');
+		value = FROM_LATIN1(start, output-start).simplifyWhiteSpace();
+		// skip to the end of line
+		while (*output != '\0' && *output != '\n')
+		    output++;
+		// get rid of the braces at the begining and the end
+		value.remove(0, 1);
+		if (value[value.length()-1] == '}') {
+		    value = value.left(value.length()-1);
+		}
+	    }
+	    reg->cookedValue = value;
+	}
+	else
+	{
+	    // the rest of the line is the register value
+	    start = output;
+	    output = strchr(output,'\n');
+	    if (output == 0)
+		output = start + strlen(start);
+	    value = FROM_LATIN1(start, output-start).simplifyWhiteSpace();
+
 	    /*
-	     * Some modern gdbs explicitly say: "0.1234 (raw 0x3e4567...)".
-	     * Here the raw value is actually in the second part.
+	     * We split the raw from the cooked values. For this purpose,
+	     * we split off the first token (separated by whitespace). It
+	     * is the raw value. The remainder of the line is the cooked
+	     * value.
 	     */
-	    if (reg->cookedValue.left(5) == "(raw ") {
-		QString raw = reg->cookedValue.right(reg->cookedValue.length()-5);
-		if (raw[raw.length()-1] == ')')	/* remove closing bracket */
-		    raw = raw.left(raw.length()-1);
-		reg->cookedValue = reg->rawValue;
-		reg->rawValue = raw;
+	    int pos = value.find(' ');
+	    if (pos < 0) {
+		reg->rawValue = value;
+		reg->cookedValue = QString();
+	    } else {
+		reg->rawValue = value.left(pos);
+		reg->cookedValue = value.mid(pos+1);
+		/*
+		 * Some modern gdbs explicitly say: "0.1234 (raw 0x3e4567...)".
+		 * Here the raw value is actually in the second part.
+		 */
+		if (reg->cookedValue.left(5) == "(raw ") {
+		    QString raw = reg->cookedValue.right(reg->cookedValue.length()-5);
+		    if (raw[raw.length()-1] == ')')	/* remove closing bracket */
+			raw = raw.left(raw.length()-1);
+		    reg->cookedValue = reg->rawValue;
+		    reg->rawValue = raw;
+		}
 	    }
 	}
+	if (*output != '\0')
+	    output++;			/* skip '\n' */
 
 	regs.append(reg);
     }
