@@ -1,4 +1,4 @@
-// $Id: gdbdriver.h,v 1.12 2000/08/18 13:53:30 jsixt Exp $
+// $Id: gdbdriver.h,v 1.12.2.1 2002/01/01 17:01:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -47,7 +47,7 @@ public:
     virtual void terminate();
     virtual void detachAndTerminate();
     virtual void interruptInferior();
-    virtual VarTree* parseQCharArray(const char* output, bool wantErrorValue);
+    virtual VarTree* parseQCharArray(const char* output, bool wantErrorValue, bool qt3like);
     virtual void parseBackTrace(const char* output, QList<StackFrame>& stack);
     virtual bool parseFrameChange(const char* output, int& frameNo,
 				  QString& file, int& lineNo, DbgAddr& address);
