@@ -1,5 +1,5 @@
 /*
- * $Id: ktreeview.h,v 1.10.2.2 2001/12/29 20:12:16 jsixt Exp $
+ * $Id: ktreeview.h,v 1.10.2.3 2003/09/07 18:36:22 jsixt Exp $
  * 
  * KTreeView class interface
  * 
@@ -26,7 +26,7 @@
 #define KDE_KTREE_VIEW_H
 
 #include <qpixmap.h>			/* used in items */
-#include <qstack.h>			/* used to specify tree paths */
+#include <qptrstack.h>			/* used to specify tree paths */
 #include <qstring.h>			/* used in items */
 #include "tableview.h"			/* base class for widget */
 
