@@ -1,4 +1,4 @@
-// $Id: main.cpp,v 1.21.2.3 2002/03/09 21:25:24 jsixt Exp $
+// $Id: main.cpp,v 1.21.2.5 2003/06/09 19:59:03 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -46,14 +46,11 @@ int main(int argc, char** argv)
 		  "by Johannes Sixt <Johannes.Sixt@telecom.at>\n"
 		  "with the help of many others");
 #else
-    static const char* description =
-	i18n("A Debugger");
-
     KAboutData aboutData("kdbg", "KDbg",
 			 VERSION,
-			 description,
+			 I18N_NOOP("A Debugger"),
 			 KAboutData::License_GPL, 
-			 "(c) 1998-2001 Johannes Sixt",
+			 "(c) 1998-2003 Johannes Sixt",
 			 0,		/* any text */
 			 "http://members.nextra.at/johsixt/kdbg.html",
 			 "Johannes.Sixt@telecom.at");
