@@ -1,4 +1,4 @@
-// $Id: mainwndbase.cpp,v 1.33 2000/09/04 20:08:18 jsixt Exp $
+// $Id: mainwndbase.cpp,v 1.33.2.2 2002/03/22 20:33:25 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -45,9 +45,6 @@
 
 #define MAX_RECENT_FILES 4
 
-
-KStdAccel* keys = 0;
-
 WatchWindow::WatchWindow(QWidget* parent, const char* name, WFlags f) :
 	QWidget(parent, name, f),
 	m_watchEdit(this, "watch_edit"),
@@ -411,11 +408,6 @@ void DebuggerMainWndBase::updateUIItem(UpdateUI* item)
 	item->enable(m_debugger->haveExecutable());
 	break;
     }
-    
-    // update statusbar
-    dbgStatusBar()->changeItem(m_debugger->isProgramActive() ?
-			    static_cast<const char*>(m_statusActive) : "",
-			    ID_STATUS_ACTIVE);
 }
 
 void DebuggerMainWndBase::updateLineItems()
