@@ -1,4 +1,4 @@
-// $Id: memwindow.h,v 1.5.2.1 2001/12/14 21:05:22 jsixt Exp $
+// $Id: memwindow.h,v 1.5.2.3 2003/09/07 18:36:22 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -11,11 +11,11 @@
 #include <qcombobox.h>
 #include <qlayout.h>
 #include <qdict.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qmap.h>
 
 class KDebugger;
-class KSimpleConfig;
+class KConfigBase;
 struct MemoryDump;
 
 class MemoryWindow : public QWidget
@@ -50,8 +50,8 @@ public slots:
     void slotNewExpression(const QString&);
     void slotTypeChange(int id);
     void slotNewMemoryDump(const QString&, QList<MemoryDump>&);
-    void saveProgramSpecific(KSimpleConfig* config);
-    void restoreProgramSpecific(KSimpleConfig* config);
+    void saveProgramSpecific(KConfigBase* config);
+    void restoreProgramSpecific(KConfigBase* config);
 };
 
 #endif // MEMWINDOW_H
