@@ -1,4 +1,4 @@
-// $Id: procattach.h,v 1.1 1998/11/07 18:32:07 jsixt Exp $
+// $Id: procattach.h,v 1.2 1999/12/11 18:17:46 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -8,8 +8,8 @@
 
 #include <qdialog.h>
 #include <qlabel.h>
-#include <qlined.h>
-#include <qpushbt.h>
+#include <qlineedit.h>
+#include <qpushbutton.h>
 #include <qlayout.h>
 
 class ProcAttach : public QDialog
