@@ -1,4 +1,4 @@
-// $Id: sourcewnd.cpp,v 1.7.2.4 2002/01/20 17:37:51 jsixt Exp $
+// $Id: sourcewnd.cpp,v 1.7.2.5 2004/05/19 20:35:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -40,12 +40,12 @@ SourceWindow::SourceWindow(const char* fileName, QWidget* parent, const char* na
     m_brkcond = loader->loadIcon("brkcond.xpm");
     setFont(kapp->fixedFont);
 #else
-    m_pcinner = BarIcon("pcinner");
-    m_pcup = BarIcon("pcup");
-    m_brkena = BarIcon("brkena");
-    m_brkdis = BarIcon("brkdis");
-    m_brktmp = BarIcon("brktmp");
-    m_brkcond = BarIcon("brkcond");
+    m_pcinner = UserIcon("pcinner");
+    m_pcup = UserIcon("pcup");
+    m_brkena = UserIcon("brkena");
+    m_brkdis = UserIcon("brkdis");
+    m_brktmp = UserIcon("brktmp");
+    m_brkcond = UserIcon("brkcond");
     setFont(KGlobalSettings::fixedFont());
 #endif
 }
