@@ -1,4 +1,4 @@
-// $Id: threadlist.cpp,v 1.1.2.1 2001/12/29 20:12:16 jsixt Exp $
+// $Id: threadlist.cpp,v 1.1.2.2 2004/05/19 20:35:51 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -49,7 +49,7 @@ ThreadList::ThreadList(QWidget* parent, const char* name) :
     KIconLoader* loader = kapp->getIconLoader();
     m_focusIcon = loader->loadIcon("pcinner.xpm");
 #else
-    m_focusIcon = BarIcon("pcinner");
+    m_focusIcon = UserIcon("pcinner");
 #endif
     makeNoFocusIcon();
 
