@@ -1,4 +1,4 @@
-// $Id: threadlist.h,v 1.1 2000/05/21 19:54:22 jsixt Exp $
+// $Id: threadlist.h,v 1.1.2.1 2003/09/07 18:36:22 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -7,7 +7,7 @@
 #define THREADLIST_H
 
 #include <qlistview.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpixmap.h>
 
 class ThreadInfo;
