@@ -1,4 +1,4 @@
-// $Id: ttywnd.cpp,v 1.8 2001/01/21 14:01:20 jsixt Exp $
+// $Id: ttywnd.cpp,v 1.8.2.1 2002/08/31 19:51:00 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -32,6 +32,9 @@
 #ifdef HAVE_LIBUTIL_H
 #include <libutil.h>			/* openpty on FreeBSD */
 #endif
+#ifdef HAVE_UTIL_H			/* openpty on NetBSD, OpenBSD */
+#include <util.h>
+#endif
 #include <errno.h>
 
 #include "mydebug.h"
