@@ -1,10 +1,10 @@
-// $Id: typetable.cpp,v 1.8.2.1 2002/01/01 17:01:51 jsixt Exp $
+// $Id: typetable.cpp,v 1.8.2.2 2003/09/07 18:36:22 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
 
 #include <qdir.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #if QT_VERSION < 200
 #include <kapp.h>
 #else
