@@ -1,4 +1,4 @@
-// $Id: winstack.h,v 1.31 2000/05/20 15:19:42 jsixt Exp $
+// $Id: winstack.h,v 1.31.2.1 2003/09/07 18:36:22 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -6,7 +6,7 @@
 #ifndef WINSTACK_H
 #define WINSTACK_H
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qdialog.h>
 #include <qlineedit.h>
 #include <qlayout.h>
